"use strict";(self["webpackChunk_quetz_frontend_main_app"]=self["webpackChunk_quetz_frontend_main_app"]||[]).push([[170,2671],{42671:(n,e,i)=>{i.r(e);i.d(e,{default:()=>b});var o=i(18303);var t=i.n(o);var a=i(44198);var l=i.n(a);var u;(function(n){n.loginGitHub="@quetz-frontend/login-extension:login-GitHub";n.loginGoogle="@quetz-frontend/login-extension:login-Google";n.loginAzure="@quetz-frontend/login-extension:login-Azure";n.loginGitLab="@quetz-frontend/login-extension:login-GitLab"})(u||(u={}));const g={id:"@quetz-frontend/login-extension:GitHub",autoStart:true,requires:[a.IMenu],activate:(n,e)=>{const i=o.PageConfig.getOption("github_login_available")==="true";n.commands.addCommand(u.loginGitHub,{label:()=>"Sign in with GitHub",isEnabled:()=>i,isVisible:()=>i&&e.profile===null,execute:()=>{window.location.href="/auth/github/login"}});e.addItem({command:u.loginGitHub})}};const d={id:"@quetz-frontend/login-extension:Google",autoStart:true,requires:[a.IMenu],activate:(n,e)=>{const i=o.PageConfig.getOption("google_login_available")==="true";n.commands.addCommand(u.loginGoogle,{label:()=>"Sign in with Google",isEnabled:()=>i,isVisible:()=>i&&e.profile===null,execute:()=>{window.location.href="/auth/google/login"}});e.addItem({command:u.loginGoogle})}};const r={id:"@quetz-frontend/login-extension:Azure",autoStart:true,requires:[a.IMenu],activate:(n,e)=>{const i=o.PageConfig.getOption("azuread_login_available")==="true";n.commands.addCommand(u.loginAzure,{label:()=>"Sign in with Azure",isEnabled:()=>i,isVisible:()=>i&&e.profile===null,execute:()=>{window.location.href="/auth/azure/login"}});e.addItem({command:u.loginAzure})}};const s={id:"@quetz-frontend/login-extension:GitLab",autoStart:true,requires:[a.IMenu],activate:(n,e)=>{const i=o.PageConfig.getOption("gitlab_login_available")==="true";n.commands.addCommand(u.loginGitLab,{label:()=>"Sign in with GitLab",isEnabled:()=>i,isVisible:()=>i&&e.profile===null,execute:()=>{window.location.href="/auth/gitlab/login"}});e.addItem({command:u.loginGitLab})}};const b=[g,d,r,s]}}]);